From: "Darrick J. Wong" <djwong@kernel.org>
To: djwong@kernel.org
Cc: linux-xfs@vger.kernel.org, david@fromorbit.com, hch@infradead.org
Subject: [PATCH 04/15] xfs: rename xfs_inode_walk functions to xfs_icwalk
Date: Wed, 02 Jun 2021 15:25:19 -0700 [thread overview]
Message-ID: <162267271913.2375284.4758622992711446717.stgit@locust> (raw)
In-Reply-To: <162267269663.2375284.15885514656776142361.stgit@locust>
From: Darrick J. Wong <djwong@kernel.org>
Shorten the prefix so that all the incore walk code has "xfs_icwalk" in
the name somewhere.
Signed-off-by: Darrick J. Wong <djwong@kernel.org>
---
fs/xfs/xfs_icache.c | 22 +++++++++++-----------
1 file changed, 11 insertions(+), 11 deletions(-)
diff --git a/fs/xfs/xfs_icache.c b/fs/xfs/xfs_icache.c
index 55c55e449cab..d5ecd4cd3ef5 100644
--- a/fs/xfs/xfs_icache.c
+++ b/fs/xfs/xfs_icache.c
@@ -26,10 +26,10 @@
#include <linux/iversion.h>
-static int xfs_inode_walk(struct xfs_mount *mp, int iter_flags,
+static int xfs_icwalk(struct xfs_mount *mp, int iter_flags,
int (*execute)(struct xfs_inode *ip, void *args),
void *args, int tag);
-static int xfs_inode_walk_ag(struct xfs_perag *pag, int iter_flags,
+static int xfs_icwalk_ag(struct xfs_perag *pag, int iter_flags,
int (*execute)(struct xfs_inode *ip, void *args),
void *args, int tag);
@@ -740,7 +740,7 @@ xfs_icache_inode_is_allocated(
* lookup reduction and stack usage. This is in the reclaim path, so we can't
* be too greedy.
*
* XXX: This will be moved closer to xfs_inode_walk* once we get rid of the
* separate reclaim walk functions.
*/
#define XFS_LOOKUP_BATCH 32
@@ -790,7 +790,7 @@ xfs_dqrele_all_inodes(
if (qflags & XFS_PQUOTA_ACCT)
eofb.eof_flags |= XFS_ICWALK_FLAG_DROP_PDQUOT;
- return xfs_inode_walk(mp, XFS_INODE_WALK_INEW_WAIT, xfs_dqrele_inode,
+ return xfs_icwalk(mp, XFS_INODE_WALK_INEW_WAIT, xfs_dqrele_inode,
&eofb, XFS_ICI_NO_TAG);
}
#endif /* CONFIG_XFS_QUOTA */
@@ -1538,7 +1538,7 @@ xfs_blockgc_worker(
if (!sb_start_write_trylock(mp->m_super))
return;
- error = xfs_inode_walk_ag(pag, 0, xfs_blockgc_scan_inode, NULL,
+ error = xfs_icwalk_ag(pag, 0, xfs_blockgc_scan_inode, NULL,
XFS_ICI_BLOCKGC_TAG);
if (error)
xfs_info(mp, "AG %u preallocation gc worker failed, err=%d",
@@ -1557,7 +1557,7 @@ xfs_blockgc_free_space(
{
trace_xfs_blockgc_free_space(mp, eofb, _RET_IP_);
- return xfs_inode_walk(mp, 0, xfs_blockgc_scan_inode, eofb,
+ return xfs_icwalk(mp, 0, xfs_blockgc_scan_inode, eofb,
XFS_ICI_BLOCKGC_TAG);
}
@@ -1634,7 +1634,7 @@ xfs_blockgc_free_quota(
* inodes with the given radix tree @tag.
*/
static int
-xfs_inode_walk_ag(
+xfs_icwalk_ag(
struct xfs_perag *pag,
int iter_flags,
int (*execute)(struct xfs_inode *ip, void *args),
@@ -1740,7 +1740,7 @@ xfs_inode_walk_ag(
/* Fetch the next (possibly tagged) per-AG structure. */
static inline struct xfs_perag *
-xfs_inode_walk_get_perag(
+xfs_icwalk_get_perag(
struct xfs_mount *mp,
xfs_agnumber_t agno,
int tag)
@@ -1755,7 +1755,7 @@ xfs_inode_walk_get_perag(
* @tag.
*/
static int
-xfs_inode_walk(
+xfs_icwalk(
struct xfs_mount *mp,
int iter_flags,
int (*execute)(struct xfs_inode *ip, void *args),
@@ -1767,9 +1767,9 @@ xfs_inode_walk(
int last_error = 0;
xfs_agnumber_t agno = 0;
- while ((pag = xfs_inode_walk_get_perag(mp, agno, tag))) {
+ while ((pag = xfs_icwalk_get_perag(mp, agno, tag))) {
agno = pag->pag_agno + 1;
- error = xfs_inode_walk_ag(pag, iter_flags, execute, args, tag);
+ error = xfs_icwalk_ag(pag, iter_flags, execute, args, tag);
xfs_perag_put(pag);
if (error) {
last_error = error;
next prev parent reply other threads:[~2021-06-02 22:25 UTC|newest]
Thread overview: 26+ messages / expand[flat|nested] mbox.gz Atom feed top
2021-06-02 22:24 [PATCHSET v6 00/15] xfs: clean up incore inode walk functions Darrick J. Wong
2021-06-02 22:25 ` [PATCH 01/15] xfs: move the quotaoff dqrele inode walk into xfs_icache.c Darrick J. Wong
2021-06-02 22:25 ` [PATCH 02/15] xfs: detach inode dquots at the end of inactivation Darrick J. Wong
2021-06-02 22:25 ` [PATCH 03/15] xfs: move the inode walk functions further down Darrick J. Wong
2021-06-02 22:25 ` Darrick J. Wong [this message]
2021-06-03 1:02 ` [PATCH 04/15] xfs: rename xfs_inode_walk functions to xfs_icwalk Dave Chinner
2021-06-02 22:25 ` [PATCH 05/15] xfs: pass the goal of the incore inode walk to xfs_inode_walk() Darrick J. Wong
2021-06-03 1:04 ` Dave Chinner
2021-06-02 22:25 ` [PATCH 06/15] xfs: separate the dqrele_all inode grab logic from xfs_inode_walk_ag_grab Darrick J. Wong
2021-06-03 1:08 ` Dave Chinner
2021-06-02 22:25 ` [PATCH 07/15] xfs: move xfs_inew_wait call into xfs_dqrele_inode Darrick J. Wong
2021-06-02 22:25 ` [PATCH 08/15] xfs: remove iter_flags parameter from xfs_inode_walk_* Darrick J. Wong
2021-06-03 1:09 ` Dave Chinner
2021-06-03 1:38 ` Darrick J. Wong
2021-06-02 22:25 ` [PATCH 09/15] xfs: remove indirect calls from xfs_inode_walk{,_ag} Darrick J. Wong
2021-06-03 1:12 ` Dave Chinner
2021-06-02 22:25 ` [PATCH 10/15] xfs: clean up inode state flag tests in xfs_blockgc_igrab Darrick J. Wong
2021-06-03 1:13 ` Dave Chinner
2021-06-02 22:25 ` [PATCH 11/15] xfs: make the icwalk processing functions clean up the grab state Darrick J. Wong
2021-06-03 1:14 ` Dave Chinner
2021-06-02 22:26 ` [PATCH 12/15] xfs: fix radix tree tag signs Darrick J. Wong
2021-06-02 22:26 ` [PATCH 13/15] xfs: pass struct xfs_eofblocks to the inode scan callback Darrick J. Wong
2021-06-02 22:26 ` [PATCH 14/15] xfs: merge xfs_reclaim_inodes_ag into xfs_inode_walk_ag Darrick J. Wong
2021-06-02 22:26 ` [PATCH 15/15] xfs: refactor per-AG inode tagging functions Darrick J. Wong
2021-06-03 1:16 ` Dave Chinner
2021-06-03 1:27 ` Darrick J. Wong
Reply instructions:
You may reply publicly to this message via plain-text email
using any one of the following methods:
* Save the following mbox file, import it into your mail client,
and reply-to-all from there: mbox
Avoid top-posting and favor interleaved quoting:
https://en.wikipedia.org/wiki/Posting_style#Interleaved_style
* Reply using the --to, --cc, and --in-reply-to
switches of git-send-email(1):
git send-email \
--in-reply-to=162267271913.2375284.4758622992711446717.stgit@locust \
--to=djwong@kernel.org \
--cc=david@fromorbit.com \
--cc=hch@infradead.org \
--cc=linux-xfs@vger.kernel.org \
/path/to/YOUR_REPLY
https://kernel.org/pub/software/scm/git/docs/git-send-email.html
* If your mail client supports setting the In-Reply-To header
@@ -740,7 +740,7 @@ xfs_icache_inode_is_allocated(
* be too greedy.
*
- * XXX: This will be moved closer to xfs_inode_walk* once we get rid of the
+ * XXX: This will be moved closer to xfs_icwalk* once we get rid of the
* separate reclaim walk functions.
*/
via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line
before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox